// java wrapper for vtkXMLPRectilinearGridWriter object
//

package vtk;
import vtk.*;

public class vtkXMLPRectilinearGridWriter extends vtkXMLPStructuredDataWriter
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native long GetInput_2();
  public vtkRectilinearGrid GetInput() {
    long temp = GetInput_2();

    if (temp == 0) return null;
    return (vtkRectilinearGrid)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native String GetDefaultFileExtension_3();
  public String GetDefaultFileExtension()
    { return GetDefaultFileExtension_3(); }

  public vtkXMLPRectilinearGridWriter() { super(); }

  public vtkXMLPRectilinearGridWriter(long id) { super(id); }
  public native long   VTKInit();

}
